"""
Constants used in this app
"""

# Django
from django.utils.text import slugify

# AA ESI Status
from esistatus import __version__

VERBOSE_NAME = "AA ESI Status for Alliance Auth"

slugified_name: str = slugify(value=VERBOSE_NAME, allow_unicode=True)
github_url: str = "https://github.com/ppfeufer/aa-esi-status"

USER_AGENT = f"{slugified_name} v{__version__} {github_url}"



# Generated by Django 3.1.2 on 2020-10-11 10:56

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="EsiStatus",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
            ],
            options={
                "permissions": (("basic_access", "Can access this app"),),
                "managed": False,
                "default_permissions": (),
            },
        ),
    ]



"""
Test the apps' template tags
"""

# Django
from django.template import Context, Template
from django.test import TestCase

# AA ESI Status
from esistatus import __version__


class TestVersionedStatic(TestCase):
    """
    Test the esistatus_static template tag
    """

    def test_versioned_static(self):
        """
        Test should return a versioned static file

        :return:
        :rtype:
        """

        context = Context(dict_={"version": __version__})
        template_to_render = Template(
            template_string=(
                "{% load esistatus %}"
                "{% esistatus_static 'esistatus/css/esistatus.min.css' %}"
            )
        )

        rendered_template = template_to_render.render(context=context)

        self.assertInHTML(
            needle=f'/static/esistatus/css/esistatus.min.css?v={context["version"]}',
            haystack=rendered_template,
        )



"""
App config
"""

# Django
from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _

# AA ESI Status
from esistatus import __version__


class AaEsiStatusConfig(AppConfig):
    """
    Application config
    """

    name = "esistatus"
    label = "esistatus"
    verbose_name = _(f"ESI Status v{__version__}")
